@@ -29,8 +29,8 @@ MAX_HISTORY = 1 << 20
 # SEL=0, Gain=1.98, Rang: 0 - 690mA, Resolution: 5mA
 # SEL=1, Gain=119.52, Rang: 0 - 11mA, Resolution: 50uA
 GAIN_SELECT = 0
-SAMPLE_RATE = 60000     # Hz
-LOG2AVG     = 1
+SAMPLE_RATE = 128000     # Hz
+LOG2AVG     = 4
 
 # using baud rate to configure voltmeter
 BAUDRATE = 0x40000000 | (GAIN_SELECT << 29) | (7 << 26) | (LOG2AVG << 20) | int(SAMPLE_RATE)
@@ -45,7 +45,7 @@ class Probe(pg.QtCore.QThread):
     def __init__(self):
         super().__init__()
         self.done = False
-        self.data = np.empty((4, 1 << 12))
+        self.data = np.empty((3, 1 << 12))
         self.index = 0
         self.n = 0
         self._gain = GAIN_SELECT
@@ -78,7 +78,7 @@ class Probe(pg.QtCore.QThread):
         n = AVERAGE_N
         bytes_count = 0
         samples_count = 0
-        t1 = time.monotonic_ns()
+        t1 = time.time()
 
         # output = 'data.csv'
         # self.f = open(output, 'w')
@@ -120,10 +120,10 @@ class Probe(pg.QtCore.QThread):
 
             bytes_count += 16
             samples_count += n*8
-            t2 = time.monotonic_ns()
+            t2 = time.time()
             dt = t2 - t1
             # if samples_count >= SAMPLE_RATE:
-            if dt >= 1000000000:
+            if dt >= 1.:
                 t1 = t2
                 print('data rate: {} bytes/s, samples: {}, dt: {}'.format(bytes_count, samples_count, dt / 1000000))
                 bytes_count = 0
@@ -364,12 +364,14 @@ class MainWindow(pg.QtGui.QMainWindow):
 
     def update(self):
         if not (self.freezed or self.probe.done):
-            r = self.widget.viewRange()
             data, size = self.probe.get()
+            if size == 0:
+                return
+            r = self.widget.viewRange()
             n = data[0][size-1]
             if n >= r[0][1]:
                 if self.auto_range:
-                    start = np.max(size - int(SAMPLE_RATE * (n - r[0][0])), 0)
+                    start = np.max((size - int(SAMPLE_RATE * (n - r[0][0])), 0))
                     ymax = np.max(data[2][start:size])
                     ymin = np.min(data[2][start:size])
 
